( cd usr/lib ; rm -rf libglib-1.2.so.0 )
( cd usr/lib ; ln -sf libglib-1.2.so.0.0.10 libglib-1.2.so.0 )
( cd usr/lib ; rm -rf libglib.so )
( cd usr/lib ; ln -sf libglib-1.2.so.0.0.10 libglib.so )
( cd usr/lib ; rm -rf libgmodule-1.2.so.0 )
( cd usr/lib ; ln -sf libgmodule-1.2.so.0.0.10 libgmodule-1.2.so.0 )
( cd usr/lib ; rm -rf libgmodule.so )
( cd usr/lib ; ln -sf libgmodule-1.2.so.0.0.10 libgmodule.so )
( cd usr/lib ; rm -rf libgthread-1.2.so.0 )
( cd usr/lib ; ln -sf libgthread-1.2.so.0.0.10 libgthread-1.2.so.0 )
( cd usr/lib ; rm -rf libgthread.so )
( cd usr/lib ; ln -sf libgthread-1.2.so.0.0.10 libgthread.so )
